Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1574)

Unified Diff: base/process/launch.h

Issue 23480061: GTTF: launch test processes using job objects on Windows. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | base/process/launch_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/process/launch.h
diff --git a/base/process/launch.h b/base/process/launch.h
index 944c1bc042fc4ff6ccb4440e3684377a6dee20b7..ac2df5eee5f751c3c718190a62db078dbc826835 100644
--- a/base/process/launch.h
+++ b/base/process/launch.h
@@ -164,12 +164,9 @@ BASE_EXPORT void CloseSuperfluousFds(const InjectiveMultimap& saved_map);
#endif // defined(OS_POSIX)
#if defined(OS_WIN)
-// Set JOBOBJECT_EXTENDED_LIMIT_INFORMATION to JobObject |job_object|.
-// As its limit_info.BasicLimitInformation.LimitFlags has
-// JOB_OBJECT_LIMIT_KILL_ON_JOB_CLOSE.
-// When the provide JobObject |job_object| is closed, the binded process will
-// be terminated.
-BASE_EXPORT bool SetJobObjectAsKillOnJobClose(HANDLE job_object);
+// Set |job_object|'s JOBOBJECT_EXTENDED_LIMIT_INFORMATION
+// BasicLimitInformation.LimitFlags to |limit_flags|.
+BASE_EXPORT bool SetJobObjectLimitFlags(HANDLE job_object, DWORD limit_flags);
// Output multi-process printf, cout, cerr, etc to the cmd.exe console that ran
// chrome. This is not thread-safe: only call from main thread.
« no previous file with comments | « no previous file | base/process/launch_win.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698